@@ -1,12 +1,12 @@
 package Bot::Backbone::Bot;
 {
-  $Bot::Backbone::Bot::VERSION = '0.140280';
+  $Bot::Backbone::Bot::VERSION = '0.140490';
 }
 use v5.10;
 use Moose;
 
 use Bot::Backbone::Types qw( EventLoop ServiceList );
-use POE qw( Loop::EV );
+use POE qw( Loop::AnyEvent );
 
 # ABSTRACT: Provides backbone services to your bot
 
@@ -89,7 +89,7 @@ Bot::Backbone::Bot - Provides backbone services to your bot
 
 =head1 VERSION
 
-version 0.140280
+version 0.140490
 
 =head1 SYNOPSIS
 
@@ -156,8 +156,6 @@ This thing sort of kind of needs L<POE> to be any kind of useful. However, L<POE
 
 Second, if you use the Jabber chat service, you need L<AnyEvent>. Mostly, L<AnyEvent> and L<POE> seem to get along, but it's slow and I've found that timers, in particular, just plain don't work quite right.
 
-Finally, in order to marry AnyEvent and POE in a way that is faster and seems to work more consisently, I also require the use of L<POE::Loop::EV>, which, of course, depends on L<EV>. If that's a problem for you, drop me a line or submit a patch and we'll see if we can work this problem out.
-
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
